<?php
/*
Plugin Name: Blog Introduction
Plugin URI: http://jussi.ruokomaki.fi/tech/wp-blog-introduction/
Author: Jussi Ruokom&auml;ki
Version: 1.5.2
Author URI: http://jussi.ruokomaki.fi/
Description: Displays heading and contents of certain page on the home page right before the posts. Hide this special page by making it private. <a href="options-general.php?page=blog-introduction.php">Configure the plugin and make it shown in the settings page.</a> 
*/

$blog_introduction_printed = false;

$bintro_enabled_data = 0;
add_option('bintro_enabled', $bintro_enabled_data);
$bintro_enabled = get_option('bintro_enabled');

$bintro_page_permalink_data = 'blog-introduction';
add_option('bintro_page_permalink', $bintro_page_permalink_data);
$bintro_page_permalink = get_option('bintro_page_permalink');

$bintro_show_heading_data = 1;
add_option('bintro_show_heading', $bintro_show_heading_data);
$bintro_show_heading = get_option('bintro_show_heading');

$bintro_show_content_data = 1;
add_option('bintro_show_content', $bintro_show_content_data);
$bintro_show_content = get_option('bintro_show_content');

$bintro_show_for_data = 'all';
add_option('bintro_show_for', $bintro_show_for_data);
$bintro_show_for = get_option('bintro_show_for');

$bintro_show_on_pages_data = 'all';
add_option('bintro_show_on_pages', $bintro_show_on_pages_data);
$bintro_show_on_pages = get_option('bintro_show_on_pages');

$bintro_heading_tag_data = 'h2';
add_option('bintro_heading_tag', $bintro_heading_tag_data);
$bintro_heading_tag = get_option('bintro_heading_tag');

$bintro_size_heading_data = '';
add_option('bintro_size_heading', $bintro_size_heading_data);
$bintro_size_heading = get_option('bintro_size_heading');

$bintro_size_content_data = '';
add_option('bintro_size_content', $bintro_size_content_data);
$bintro_size_content = get_option('bintro_size_content');

$bintro_debug_data = 0;
add_option('bintro_debug', $bintro_debug_data);
$bintro_debug = get_option('bintro_debug');

function bintro_get() {
  global $blog_introduction_printed, $bintro_page_permalink, $bintro_show_for, 
    $bintro_heading_tag, $bintro_size_heading, $bintro_size_content, $bintro_debug,
    $bintro_show_heading, $bintro_show_content;

  if ($bintro_show_for != 'all') {
    if (($bintro_show_for == 'users' && !is_user_logged_in()) ||
        ($bintro_show_for == 'visitors' && is_user_logged_in())) {
      return false;
    }
  }

  if (is_numeric($bintro_page_permalink)) {
    $page = get_page($bintro_page_permalink);
  } else {
    $page = get_page_by_path($bintro_page_permalink);
  }

  $str = '';

  if ($bintro_debug) { $str .= '<!--'; }

  $str  = '<div id="blog_introduction">' . "\n";
  if ($bintro_show_heading) {
  $str .= '  <div id="blog_introduction_heading">' . "\n";
  $str .= '      <' . $bintro_heading_tag . ($bintro_size_heading != '' ? ' style="font-size: ' . $bintro_size_heading . ';"' : '') . '>' .  $page->post_title . '</' . $bintro_heading_tag . '>' . "\n";
  $str .= '  </div>' . "\n";
  }
  if ($bintro_show_content) {
  $str .= '  <div id="blog_introduction_content"' . ($bintro_size_content != '' ? ' style="font-size: ' . $bintro_size_content . ';"' : '') . '>' . "\n";
  $str .= $page->post_content . "\n";
  $str .= '  </div>' . "\n";
  }
  $str .= '</div>' . "\n";

  if ($bintro_debug) { $str .= '-->'; }

  return $str;

} // ends bintro_get


function bintro_print() { 
  global $blog_introduction_printed, $bintro_enabled, $bintro_show_on_pages;

  $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

  if ($bintro_enabled && is_home() && ($paged == 1 || $bintro_show_on_pages == 'all')) {
    if (!$blog_introduction_printed) {
      echo bintro_get();
      $blog_introduction_printed = true;
    }
  } 
}


function bintro_add_options_page() {
  add_options_page('Blog Introduction', 'Blog Introduction', 8, basename(__FILE__), 'bintro_options_page');
}

function bintro_options_page() { ?>

<div class="wrap">

  <h2><?= __('Blog Introduction Settings') ?></h2>

  <form method="post" action="options.php">

    <?php wp_nonce_field('update-options'); ?>

    <p class="submit">
      <input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
    </p>

    <table border="0" style="vertical-align: top;" cellspacing="10">
      <tr>
       <td style="vertical-align: top;"><strong><?= __('Show intro:') ?></strong></td>
       <td style="vertical-align: top;">
         <input type="radio" name="bintro_enabled" value="1" <?= get_option('bintro_enabled') == '1' ? 'checked="checked"' : ''  ?> /> <span style="color: #060"><?= __('Yes') ?></span><br />
         <input type="radio" name="bintro_enabled" value="0" <?= get_option('bintro_enabled') == '0' ? 'checked="checked"' : ''  ?> /> <span style="color: #600"><?= __('No') ?></span><br />
       </td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __("Whether intro is shown. See preview to make sure all settings are correct, then show it to the world.") . '<br />' . __('Default') . ': ' . __('No') ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;" width="20%"><?= __('Page id/permalink:') ?></td>
       <td style="vertical-align: top;" width="30%"><input type="text" name="bintro_page_permalink" value="<?php echo get_option('bintro_page_permalink'); ?>" /></td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __('Enter page id (numeric, e.g. "8") or its permalink (string, e.g. "my-intro-page"). (Page id is shown in the url when you edit the page.)') . '<br />' . __('Default') . ': blog-introduction' ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Show heading:') ?></td>
       <td style="vertical-align: top;">
         <input type="radio" name="bintro_show_heading" value="1" <?= get_option('bintro_show_heading') == '1' ? 'checked="checked"' : ''  ?> /> <?= __('Yes') ?><br />
         <input type="radio" name="bintro_show_heading" value="0" <?= get_option('bintro_show_heading') == '0' ? 'checked="checked"' : ''  ?> /> <?= __('No') ?><br />
       </td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __("Whether plugin should show heading (from chosen page).") . '<br />' . __('Default') . ': ' . __('Yes') ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Show content:') ?></td>
       <td style="vertical-align: top;">
         <input type="radio" name="bintro_show_content" value="1" <?= get_option('bintro_show_content') == '1' ? 'checked="checked"' : ''  ?> /> <?= __('Yes') ?><br />
         <input type="radio" name="bintro_show_content" value="0" <?= get_option('bintro_show_content') == '0' ? 'checked="checked"' : ''  ?> /> <?= __('No') ?><br />
       </td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __("Whether plugin should show content (from chosen page).") . '<br />' . __('Default') . ': ' . __('Yes') ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Wrapper tag for heading:') ?></td>
       <td style="vertical-align: top;"><input type="text" name="bintro_heading_tag" value="<?php echo get_option('bintro_heading_tag'); ?>" /></td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __('Enter tag without &lt;angle brackets&gt;.') . '<br />' . __('Default') . ': h2' ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Show blog introduction for:') ?></td>
       <td style="vertical-align: top;">
         <input type="radio" name="bintro_show_for" value="all" <?= get_option('bintro_show_for') == 'all' ? 'checked="checked"' : ''  ?> /> <?= __('Everyone') ?><br />
         <input type="radio" name="bintro_show_for" value="users" <?= get_option('bintro_show_for') == 'users' ? 'checked="checked"' : ''  ?> /> <?= __('Authenticated users only') ?><br />
         <input type="radio" name="bintro_show_for" value="visitors" <?= get_option('bintro_show_for') == 'visitors' ? 'checked="checked"' : ''  ?> /> <?= __('Unauthenticated visitors only') ?>
       </td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __('To whom the introduction should be shown.') . '<br />' . __('Default') . ': ' . __('Everyone') ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Show on all pages of front page:') ?></td>
       <td style="vertical-align: top;">
         <input type="radio" name="bintro_show_on_pages" value="all" <?= get_option('bintro_show_on_pages') == 'all' ? 'checked="checked"' : ''  ?> /> <?= __('Yes (pages 1, 2, etc)') ?><br />
         <input type="radio" name="bintro_show_on_pages" value="first" <?= get_option('bintro_show_on_pages') == 'first' ? 'checked="checked"' : ''  ?> /> <?= __('No (first page only)') ?><br />
       </td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __("What front pages the introduction should be shown on.") . '<br />' . __('Default') . ': ' . __('Yes') ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Size for heading:') ?></td>
       <td style="vertical-align: top;"><input type="text" name="bintro_size_heading" value="<?php echo get_option('bintro_size_heading'); ?>" /></td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __('Defines a specific font size for the heading (via CSS font-size markup). (E.g. "120%", "x-large" or "1.5em".)') . '<br />' . __('Default') . ': ' . __('(empty)') ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Size for content:') ?></td>
       <td style="vertical-align: top;"><input type="text" name="bintro_size_content" value="<?php echo get_option('bintro_size_content'); ?>" /></td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __('Defines a specific font size for the content (via CSS font-size markup). (E.g. "80%", "smaller" or "0.8em".)') . '<br />' . __('Default') . ': ' . __('(empty)') ?></span></td>
      </tr>
      <tr>
       <td style="vertical-align: top;"><?= __('Enable debugging mode:') ?></td>
       <td style="vertical-align: top;">
         <input type="radio" name="bintro_debug" value="1" <?= get_option('bintro_debug') == '1' ? 'checked="checked"' : ''  ?> /> <?= __('Yes') ?><br />
         <input type="radio" name="bintro_debug" value="0" <?= get_option('bintro_debug') == '0' ? 'checked="checked"' : ''  ?> /> <?= __('No') ?><br />
       </td>
       <td style="vertical-align: top;"><span style="color: #999"><?= __("Please don't enable this if you're not sure what you're doing.") . '<br />' . __('Default') . ': ' . __('No') ?></span></td>
      </tr>
    </table>

    <input type="hidden" name="action" value="update" />

    <input type="hidden" name="page_options" value="bintro_enabled,bintro_page_permalink,bintro_show_heading,bintro_show_content,bintro_heading_tag,bintro_show_for,bintro_show_on_pages,bintro_size_heading,bintro_size_content,bintro_debug" />

    <p class="submit">
      <input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
    </p>

  </form>
<h3><?php echo __("Preview"); ?></h3>
<p>
<?php echo __("Remember to save changes to see the updated preview."); ?>
</p>
<div style="padding: 2em; border: 1px solid #ccc; overflow-x: scroll;"><code><pre>
<?php
$preview = bintro_get();
echo htmlentities($preview);
?>
</pre></code></div>

</div>

<?php
}


add_action('loop_start', 'bintro_print');

add_action('admin_menu', 'bintro_add_options_page');
